import { BehaviorSubject, retry, tap, catchError, of, finalize } from 'rxjs';

let defaultErrorHandler;
let defaultRetryCount = 0;
let defaultRetryDelay = 0;
function configureHandler(config) {
    defaultErrorHandler = config.defaultErrorHandler;
    defaultRetryCount = config.defaultRetryCount ?? 0;
    defaultRetryDelay = config.defaultRetryDelay ?? 0;
}
let requestCount = 0;
let requestsSubject = new BehaviorSubject(0);
let requests$ = requestsSubject.asObservable();
function pendingRequestsCount() {
    return requests$;
}
function handle(dataSetter, loadingSetter, fallbackValue, errorHandler, retryCount = defaultRetryCount, retryDelay = defaultRetryDelay) {
    return (source$) => {
        requestCount++;
        requestsSubject.next(requestCount);
        if (loadingSetter) {
            loadingSetter(true);
        }
        return source$.pipe(retry({
            count: retryCount,
            delay: retryDelay,
            resetOnSuccess: true
        }), tap((data) => dataSetter(data)), catchError((error) => {
            if (errorHandler) {
                errorHandler(error);
            }
            else if (defaultErrorHandler) {
                defaultErrorHandler(error);
            }
            if (fallbackValue !== undefined) {
                dataSetter(fallbackValue);
                return of(fallbackValue);
            }
            return of(null);
        }), finalize(() => {
            requestCount--;
            requestCount = requestCount < 0 ? 0 : requestCount;
            requestsSubject.next(requestCount);
            if (loadingSetter) {
                loadingSetter(false);
            }
        }));
    };
}

/**
 * Generated bundle index. Do not edit.
 */

export { configureHandler, handle, pendingRequestsCount };
//# sourceMappingURL=angular-http-handler.mjs.map
